If read-write file system access is configured for Claude Code via `/allowed-tools`, it is advised to run [Claude Code](https://docs.anthropic.com/en/docs/claude-code/overview) in a dev container. For more details, refer to the [Dev Container](../.devcontainer/README.md) documentation.

## MCP servers
MCP servers are configured in the `./.mcp.json` file. The file cannot be moved to `.claude/mcp.json`.